@@ -49,6 +49,14 @@ def log_warn(*args):
 def bash(cmd):
     return subprocess.getoutput(cmd)
 
+def ngpu(maxmem = 30):# Max used memory in Mb
+    import GPUtil
+    gpus = GPUtil.getGPUs()
+    return len([g for g in gpus if g.memoryUsed < maxmem])
+
+def nsnode(*nodes):#Slurm Node Count
+   return sum([bash('squeue').count(s) for s in nodes])
+
 def parse_json(data):
     return json.loads(data.decode("utf-8"))
 
@@ -125,8 +133,10 @@ class CAM(object):
         <br>`cam worker "some start condition"`
         <br>Start condition can be specified with bash and python e.g.: 
         <br>Has Free GPU\t: "bash('nvidia-smi').count(' 0MiB /') > 2"
+        <br>Also use\t: "ngpu() > 2"
         <br>Slurm job count\t: "int(bash('squeue -h -t pending,running -r | wc -l')) < 4"
-        <br>Slurm node count\t: "bash('squeue').count('ltl-gpu')<4"
+        <br>Slurm node count\t: "bash('squeue').count('node1')<4"
+        <br>Also use\t: "nsnode("node1", "node2") < 2"
         <br>`cam worker "some start condition" prefix suffix` will add prefix and suffix to the command.
         """
         log_info("Server: ", self._conf['server'], ":", str(self._conf['port']), ' v', self.__version__)
